summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/smpppdsearcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/smpppdsearcher.h')
-rw-r--r--kopete/plugins/smpppdcs/smpppdsearcher.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kopete/plugins/smpppdcs/smpppdsearcher.h b/kopete/plugins/smpppdcs/smpppdsearcher.h
index 81c9cb03..1e96f737 100644
--- a/kopete/plugins/smpppdcs/smpppdsearcher.h
+++ b/kopete/plugins/smpppdcs/smpppdsearcher.h
@@ -30,6 +30,7 @@ class KProcess;
*/
class SMPPPDSearcher : public TQObject {
Q_OBJECT
+ TQ_OBJECT
SMPPPDSearcher(const SMPPPDSearcher&);
SMPPPDSearcher& operator=(const SMPPPDSearcher&);
@@ -59,13 +60,13 @@ protected:
* @brief Scans a network for a smpppd
*
* Scans a network for a smpppd described by
- * ip and mask.
+ * ip and tqmask.
*
* @param ip the ntwork ip
* @param mask the network mask
* @return <code>TRUE</code> if an smpppd was found
*/
- bool scan(const TQString& ip, const TQString& mask);
+ bool scan(const TQString& ip, const TQString& tqmask);
signals:
/**
@@ -59,13 +60,13 @@ protected:
*
* @param ip the ntwork ip
- * @param mask the network mask
+ * @param tqmask the network tqmask
* @return <code>TRUE</code> if an smpppd was found
*/